@@ -11,16 +11,16 @@ class DetectController(HttpController):
 
     @verify_credentials
     def register_endpoint(self, host, serial_num, tags=None):
-        """ Register (or re-register) an endpoint to your account """
-        body = dict(id=f'{host}:{serial_num}')
+        """Register (or re-register) an endpoint to your account"""
+        body = dict(id=f"{host}:{serial_num}")
         if tags:
-            body['tags'] = tags
+            body["tags"] = tags
 
         res = self._session.post(
-            f'{self.account.hq}/detect/endpoint',
+            f"{self.account.hq}/detect/endpoint",
             headers=self.account.headers,
             json=body,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.text
@@ -28,16 +28,16 @@ class DetectController(HttpController):
 
     @verify_credentials
     def update_endpoint(self, endpoint_id, tags=None):
-        """ Update an endpoint in your account """
+        """Update an endpoint in your account"""
         body = dict()
         if tags is not None:
-            body['tags'] = tags
+            body["tags"] = tags
 
         res = self._session.post(
-            f'{self.account.hq}/detect/endpoint/{endpoint_id}',
+            f"{self.account.hq}/detect/endpoint/{endpoint_id}",
             headers=self.account.headers,
             json=body,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -45,13 +45,13 @@ class DetectController(HttpController):
 
     @verify_credentials
     def delete_endpoint(self, ident: str):
-        """ Delete an endpoint from your account """
+        """Delete an endpoint from your account"""
         params = dict(id=ident)
         res = self._session.delete(
-            f'{self.account.hq}/detect/endpoint',
+            f"{self.account.hq}/detect/endpoint",
             headers=self.account.headers,
             json=params,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -59,27 +59,27 @@ class DetectController(HttpController):
 
     @verify_credentials
     def list_endpoints(self, days: int = 90):
-        """ List all endpoints on your account """
+        """List all endpoints on your account"""
         params = dict(days=days)
         res = self._session.get(
-            f'{self.account.hq}/detect/endpoint',
+            f"{self.account.hq}/detect/endpoint",
             headers=self.account.headers,
             params=params,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
         raise Exception(res.text)
 
     @verify_credentials
-    def describe_activity(self, filters: dict, view: str = 'protected'):
-        """ Get report for an Account """
+    def describe_activity(self, filters: dict, view: str = "protected"):
+        """Get report for an Account"""
         params = dict(view=view, **filters)
         res = self._session.get(
-            f'{self.account.hq}/detect/activity',
+            f"{self.account.hq}/detect/activity",
             headers=self.account.headers,
             params=params,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -87,13 +87,15 @@ class DetectController(HttpController):
 
     @verify_credentials
     def threat_hunt_activity(self, threat_hunt_id=None, test_id=None, threat_id=None):
-        """ Get threat hunt activity """
-        filters = dict(threat_hunt_id=threat_hunt_id, test_id=test_id, threat_id=threat_id)
+        """Get threat hunt activity"""
+        filters = dict(
+            threat_hunt_id=threat_hunt_id, test_id=test_id, threat_id=threat_id
+        )
         res = self._session.get(
-            f'{self.account.hq}/detect/threat_hunt_activity',
+            f"{self.account.hq}/detect/threat_hunt_activity",
             headers=self.account.headers,
             params=filters,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -101,12 +103,12 @@ class DetectController(HttpController):
 
     @verify_credentials
     def list_tests(self, filters: dict = None):
-        """ List all tests available to an account """
+        """List all tests available to an account"""
         res = self._session.get(
-            f'{self.account.hq}/detect/tests',
+            f"{self.account.hq}/detect/tests",
             headers=self.account.headers,
             params=filters if filters else {},
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -114,11 +116,11 @@ class DetectController(HttpController):
 
     @verify_credentials
     def get_test(self, test_id):
-        """ Get properties of an existing test """
+        """Get properties of an existing test"""
         res = self._session.get(
-            f'{self.account.hq}/detect/tests/{test_id}',
+            f"{self.account.hq}/detect/tests/{test_id}",
             headers=self.account.headers,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -126,11 +128,11 @@ class DetectController(HttpController):
 
     @verify_credentials
     def list_techniques(self):
-        """ List techniques """
+        """List techniques"""
         res = self._session.get(
-            f'{self.account.hq}/detect/techniques',
+            f"{self.account.hq}/detect/techniques",
             headers=self.account.headers,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -138,12 +140,12 @@ class DetectController(HttpController):
 
     @verify_credentials
     def list_threats(self):
-        """ List threats """
+        """List threats"""
         res = self._session.get(
-            f'{self.account.hq}/detect/threats',
+            f"{self.account.hq}/detect/threats",
             headers=self.account.headers,
             params={},
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -151,11 +153,11 @@ class DetectController(HttpController):
 
     @verify_credentials
     def get_threat(self, threat_id):
-        """ Get properties of an existing threat """
+        """Get properties of an existing threat"""
         res = self._session.get(
-            f'{self.account.hq}/detect/threats/{threat_id}',
+            f"{self.account.hq}/detect/threats/{threat_id}",
             headers=self.account.headers,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -163,12 +165,12 @@ class DetectController(HttpController):
 
     @verify_credentials
     def list_detections(self):
-        """ List detections """
+        """List detections"""
         res = self._session.get(
-            f'{self.account.hq}/detect/detections',
+            f"{self.account.hq}/detect/detections",
             headers=self.account.headers,
             params={},
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -176,11 +178,11 @@ class DetectController(HttpController):
 
     @verify_credentials
     def get_detection(self, detection_id):
-        """ Get properties of an existing detection """
+        """Get properties of an existing detection"""
         res = self._session.get(
-            f'{self.account.hq}/detect/detections/{detection_id}',
+            f"{self.account.hq}/detect/detections/{detection_id}",
             headers=self.account.headers,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -188,12 +190,12 @@ class DetectController(HttpController):
 
     @verify_credentials
     def list_threat_hunts(self, filters: dict = None):
-        """ List threat hunts """
+        """List threat hunts"""
         res = self._session.get(
-            f'{self.account.hq}/detect/threat_hunts',
+            f"{self.account.hq}/detect/threat_hunts",
             headers=self.account.headers,
             params=filters if filters else {},
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -201,11 +203,11 @@ class DetectController(HttpController):
 
     @verify_credentials
     def get_threat_hunt(self, threat_hunt_id):
-        """ Get properties of an existing threat hunt """
+        """Get properties of an existing threat hunt"""
         res = self._session.get(
-            f'{self.account.hq}/detect/threat_hunts/{threat_hunt_id}',
+            f"{self.account.hq}/detect/threat_hunts/{threat_hunt_id}",
             headers=self.account.headers,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -213,11 +215,11 @@ class DetectController(HttpController):
 
     @verify_credentials
     def do_threat_hunt(self, threat_hunt_id):
-        """ Run a threat hunt """
+        """Run a threat hunt"""
         res = self._session.post(
-            f'{self.account.hq}/detect/threat_hunts/{threat_hunt_id}',
+            f"{self.account.hq}/detect/threat_hunts/{threat_hunt_id}",
             headers=self.account.headers,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -225,11 +227,11 @@ class DetectController(HttpController):
 
     @verify_credentials
     def download(self, test_id, filename):
-        """ Clone a test file or attachment"""
+        """Clone a test file or attachment"""
         res = self._session.get(
-            f'{self.account.hq}/detect/tests/{test_id}/{filename}',
+            f"{self.account.hq}/detect/tests/{test_id}/{filename}",
             headers=self.account.headers,
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.content
@@ -237,16 +239,16 @@ class DetectController(HttpController):
 
     @verify_credentials
     def schedule(self, items: list):
-        """ Schedule tests and threats so endpoints will start running them
+        """Schedule tests and threats so endpoints will start running them
 
         Example: items=[dict(run_code='DAILY', tags='grp-1,grp2', test_id='123-123-123'),
                         dict(run_code='DAILY', tags='grp-1', threat_id='abc-def-ghi')]
         """
         res = self._session.post(
-            url=f'{self.account.hq}/detect/queue',
+            url=f"{self.account.hq}/detect/queue",
             headers=self.account.headers,
             json=dict(items=items),
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
@@ -254,16 +256,16 @@ class DetectController(HttpController):
 
     @verify_credentials
     def unschedule(self, items: list):
-        """ Unschedule tests and threats so endpoints will stop running them
+        """Unschedule tests and threats so endpoints will stop running them
 
         Example: items=[dict(tags='grp-1,grp2', test_id='123-123-123'),
                         dict(tags='grp-1', threat_id='abc-def-ghi')]
         """
         res = self._session.delete(
-            f'{self.account.hq}/detect/queue',
+            f"{self.account.hq}/detect/queue",
             headers=self.account.headers,
             json=dict(items=items),
-            timeout=10
+            timeout=10,
         )
         if res.status_code == 200:
             return res.json()
